@@ -1,5 +1,5 @@
 /*****************************************************************************
- * application.h - QStarDict, a StarDict clone written with using Qt         *
+ * application.h - QStarDict, a StarDict clone written using Qt              *
  * Copyright (C) 2008 Alexander Rodin                                        *
  *                                                                           *
  * This program is free software; you can redistribute it and/or modify      *
@@ -32,7 +32,9 @@ class DictCore;
 class MainWindow;
 class PopupWindow;
 class Speaker;
+#ifndef MAEMO
 class TrayIcon;
+#endif // MAEMO
 #ifdef QSTARDICT_WITH_DBUS
 class DBusAdaptor;
 #endif // QSTARDICT_WITH_DBUS
@@ -92,8 +94,10 @@ class Application: public QApplication
         /**
          * Returns a pointer to the tray icon.
          */
+        #ifndef MAEMO
         TrayIcon *trayIcon()
         { return m_trayIcon; }
+        #endif // MAEMO
 #ifdef QSTARDICT_WITH_DBUS
         /**
          * Returns a pointer to the DBusAdaptor instance.
@@ -110,10 +114,14 @@ class Application: public QApplication
         MainWindow *m_mainWindow;
         PopupWindow *m_popupWindow;
         Speaker *m_speaker;
+        #ifndef MAEMO
         TrayIcon *m_trayIcon;
+        #endif // MAEMO
 #ifdef QSTARDICT_WITH_DBUS
         DBusAdaptor *m_dbusAdaptor;
 #endif // QSTARDICT_WITH_DBUS
+
+        QString commandLineText();
 };
 
 }
